(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    505240,      12211]*)
(*NotebookOutlinePosition[    505977,      12237]*)
(*  CellTagsIndexPosition[    505933,      12233]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(<< HighEnergyPhysics`fc`\)], "Input"],

Cell[TextData[{
  StyleBox["FeynCalc",
    FontWeight->"Bold"],
  " ",
  "4.1.1",
  "    For help, type ?FeynCalc,  ",
  ButtonBox["use the built-in help system",
    ButtonFunction:>(FrontEndExecute[ 
        FrontEnd`HelpBrowserLookup[ "AddOns", #]]&),
    ButtonData:>{"Short Overview", "intro"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Open the help browser"],
  "  or visit ",
  ButtonBox["www.feyncalc.org",
    ButtonData:>{
      URL[ "http://www.feyncalc.org"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"http://www.feyncalc.org"]
}], "Text",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["I want to compute the following tensor integral", "Text"],

Cell[TextData[{
  "M= ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[
                FractionBox["1", 
                  RowBox[{
                    RowBox[{"(", 
                      
                      InterpretationBox[\("["\[InvisibleSpace]k\^2\
\[InvisibleSpace]"-"\[InvisibleSpace]my\^2\[InvisibleSpace]"]"\),
                        SequenceForm[ "[", 
                          Power[ k, 2], "-", 
                          Power[ my, 2], "]"],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      
                      InterpretationBox[\("["\[InvisibleSpace]\((k + p - q)\)\
\^2\[InvisibleSpace]"-"\[InvisibleSpace]mw\^2\[InvisibleSpace]"]"\),
                        SequenceForm[ "[", 
                          Power[ 
                            Plus[ k, p, 
                              Times[ -1, q]], 2], "-", 
                          Power[ mw, 2], "]"],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      
                      InterpretationBox[\("["\[InvisibleSpace]\((k + p + q)\)\
\^2\[InvisibleSpace]"-"\[InvisibleSpace]mw\^2\[InvisibleSpace]"]"\),
                        SequenceForm[ "[", 
                          Power[ 
                            Plus[ k, p, q], 2], "-", 
                          Power[ mw, 2], "]"],
                        Editable->False], ")"}]}]],
                "TraditionalForm"], "-", 
              FormBox[
                FractionBox["1", 
                  RowBox[{
                    RowBox[{"(", 
                      
                      InterpretationBox[\("["\[InvisibleSpace]k\^2\
\[InvisibleSpace]"-"\[InvisibleSpace]mu\^2\[InvisibleSpace]"]"\),
                        SequenceForm[ "[", 
                          Power[ k, 2], "-", 
                          Power[ mu, 2], "]"],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      
                      InterpretationBox[\("["\[InvisibleSpace]\((k + p - q)\)\
\^2\[InvisibleSpace]"-"\[InvisibleSpace]mw\^2\[InvisibleSpace]"]"\),
                        SequenceForm[ "[", 
                          Power[ 
                            Plus[ k, p, 
                              Times[ -1, q]], 2], "-", 
                          Power[ mw, 2], "]"],
                        Editable->False], ")"}], " ", 
                    RowBox[{"(", 
                      
                      InterpretationBox[\("["\[InvisibleSpace]\((k + p + q)\)\
\^2\[InvisibleSpace]"-"\[InvisibleSpace]mw\^2\[InvisibleSpace]"]"\),
                        SequenceForm[ "[", 
                          Power[ 
                            Plus[ k, p, q], 2], "-", 
                          Power[ mw, 2], "]"],
                        Editable->False], ")"}]}]],
                "TraditionalForm"]}], ")"}], " ", \(k\^\[Mu]\), " ", 
          FormBox[
            SuperscriptBox[
              FormBox["k",
                "TraditionalForm"], "2"],
            "TraditionalForm"], " ", 
          FormBox[
            RowBox[{
              FormBox["k",
                "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
              "\[NoBreak]", 
              FormBox["p",
                "TraditionalForm"]}],
            "TraditionalForm"]}], TraditionalForm]], "Output"]
}], "Text"],

Cell[BoxData[
    \(Note\ that\ the\ denominators\ are\ equal\ when\ \ mu \[Rule] my, \ 
    which\ means\ that\ the\ result\ is\ M = \(0\ if\ mu = my\)\)], "Text"],

Cell["I will define the following", "Text"],

Cell[BoxData[
    \(\(T1 = \ 
        OneLoop[k, 
          FVD[k, \[Mu]] SPD[k, p] SPD[k] 
            FAD[{k + p - q, mw}, {k + p + q, mw}, {k, my}]];\)\)], "Input"],

Cell["M is then", "Text"],

Cell[BoxData[
    \(\(T2 = T1 /. my \[Rule] mu;\)\)], "Input"],

Cell[BoxData[
    \(\(M = T1 - T2;\)\)], "Input"],

Cell["Of course M=0 when mu=my", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[M /. mu \[Rule] my]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0\)], "Output"]
}, Open  ]],

Cell["I can do the same calculation in another way:", "Text"],

Cell[BoxData[
    \(\(S1 = 
        OneLoop[k, 
          FVD[k, \[Mu]] SPD[k, p] SPD[k] 
            FAD[{k + p - q, mw}, {k + p + q, mw}, {k, my}]];\)\)], "Input"],

Cell[BoxData[
    \(\(S2 = 
        OneLoop[k, 
          FVD[k, \[Mu]] SPD[k, p] SPD[k] 
            FAD[{k + p - q, mw}, {k + p + q, mw}, {k, mu}]];\)\)], "Input"],

Cell[BoxData[
    \(\(NewM = S1 - S2;\)\)], "Input"],

Cell["Now let us check that NewM=0 when mu=my", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[NewM /. mu \[Rule] my]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(-\(1\/72\)\), " ", "\[ImaginaryI]", " ", \(\[Pi]\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"36", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", \(mw\^2\)}], "-", 
            RowBox[{"72", " ", \(\(B\_0\)(0, mw\^2, mw\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", \(mw\^2\)}], "-", 
            RowBox[{"36", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{"4", " ", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(mw\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", \(mw\^2\)}], "-", 
            RowBox[{"72", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", \(mw\^2\)}], "+", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"], " ", \(mw\^2\)}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            RowBox[{"432", " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"]}], "-", 
            RowBox[{"18", " ", \((2\ mw\^2 + my\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
            "18", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{"9", " ", \((mw\^2 - my\^2)\), " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{"9", " ", \(my\^2\), " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{"36", " ", \(my\^2\), " ", \((mw\^2 - my\^2)\), " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{"6", " ", \((mw\^2 + 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{
            "6", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{"12", " ", \(my\^2\), " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{"18", " ", \(my\^2\), " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{"9", " ", \((3\ mw\^2 - 4\ my\^2)\), " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "+", 
            RowBox[{"36", " ", \(my\^2\), " ", \((mw\^2 - my\^2)\), " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]]}], "-", 
            RowBox[{"9", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"9", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"12", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}], "-", 
            RowBox[{"18", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"2", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"18", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{"18", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{"24", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}], "+", 
            RowBox[{"36", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{"4", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}]}], "-", 
            RowBox[{"9", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "-", 
            RowBox[{"27", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "-", 
            RowBox[{"108", " ", \(my\^2\), " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"12", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"54", " ", 
              RowBox[{\(B\_0\), "(", 
                RowBox[{
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "+", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "+", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                ",", \(my\^2\), ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"36", " ", \((4\ mw\^2 - 7\ my\^2)\), " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"2", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "+", 
            RowBox[{"144", " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "-", 
            RowBox[{"288", " ", 
              RowBox[{
                FormBox[\("C"\_"0"\),
                  "TraditionalForm"], "\[NoBreak]", "(", "\[NoBreak]", 
                FormBox[
                  RowBox[{"4", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}],
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(mw\^2\),
                  "TraditionalForm"], "\[NoBreak]", ",", "\[NoBreak]", 
                FormBox[\(my\^2\),
                  "TraditionalForm"], "\[NoBreak]", ")"}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", \((my\^2 - mw\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"36", " ", \(my\^2\), " ", \((my\^2 - mw\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"216", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"936", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"36", " ", \(my\^2\), " ", \((mw\^2 - my\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"36", " ", \(my\^2\), " ", \((mw\^2 - my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \((2\ mw\^2 - 3\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"36", " ", \((2\ mw\^2 - 7\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"36", " ", \((6\ mw\^2 - 11\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"216", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"1152", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", \((my\^2 - mw\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", \((my\^2 - mw\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"1872", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", \((mw\^2 - my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \((6\ mw\^2 - 11\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"432", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"864", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"648", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"432", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"360", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"648", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"504", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"1080", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"144", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"720", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"2592", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"144", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"144", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"288", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"2448", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"72", " ", \(my\^2\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({my\^2, mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"2592", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"288", " ", \((mw\^2 - 2\ my\^2)\), " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"576", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"432", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{"4", " ", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"108", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], "+", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, my\^2}\)}], ")"}]}], "-", 
            RowBox[{"108", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], "+", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, my\^2}\)}], ")"}]}], "-", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"432", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"864", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"0", ",", "0", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{"4", " ", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"18", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], "+", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, my\^2}\)}], ")"}]}], "-", 
            RowBox[{"18", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], "+", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, my\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], "+", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, my\^2}\)}], ")"}]}], "-", 
            RowBox[{"36", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], "+", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, my\^2}\)}], ")"}]}], "-", 
            RowBox[{"18", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], "+", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, my\^2}\)}], ")"}]}], "-", 
            RowBox[{"18", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SuperscriptBox[
                        FormBox["p",
                          "TraditionalForm"], "2"], "+", 
                      RowBox[{"2", " ", 
                        RowBox[{
                          FormBox["p",
                            "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                          "\[NoBreak]", 
                          FormBox["q",
                            "TraditionalForm"]}]}], "+", 
                      SuperscriptBox[
                        FormBox["q",
                          "TraditionalForm"], "2"]}], "}"}], 
                  ",", \({mw\^2, my\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"144", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "1", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"288", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}],
                    "TraditionalForm"], ")"}], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"576", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"864", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"576", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"1152", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "1", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"576", " ", 
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"1728", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"1152", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{
                FormBox["p",
                  "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                "\[NoBreak]", 
                FormBox["q",
                  "TraditionalForm"]}], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "2"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"1", ",", "2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "-", 
            RowBox[{"1152", " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], "4"], " ", 
              RowBox[{"PaVe", "(", 
                RowBox[{"2", ",", "2", ",", "2", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "+", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{
                        SuperscriptBox[
                          FormBox["p",
                            "TraditionalForm"], "2"], "-", 
                        RowBox[{"2", " ", 
                          RowBox[{
                            FormBox["p",
                              "TraditionalForm"], "\[NoBreak]", 
                            "\[CenterDot]", "\[NoBreak]", 
                            FormBox["q",
                              "TraditionalForm"]}]}], "+", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}], ",", 
                      RowBox[{"4", " ", 
                        SuperscriptBox[
                          FormBox["q",
                            "TraditionalForm"], "2"]}]}], "}"}], 
                  ",", \({mw\^2, my\^2, mw\^2}\)}], ")"}]}], "+", 
            FractionBox[
              RowBox[{"24", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"4", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"24", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"4", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "9", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"9", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "9", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"9", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"6", " ", \((mw\^2 - my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "18", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"6", " ", \((3\ mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"6", " ", \((mw\^2 - my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "24", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"12", " ", \((2\ mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"6", " ", \((mw\^2 - my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "9", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"3", " ", \((3\ mw\^2 + my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"6", " ", \((mw\^2 - my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"36", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"6", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"36", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"6", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "4"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "4"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"24", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"4", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"24", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"4", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "27", " ", \(my\^2\), " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "18", " ", \(my\^2\), " ", \((my\^2 - mw\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"9", " ", \(my\^2\), " ", \((my\^2 - mw\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "9", " ", \((mw\^2 - 4\ my\^2)\), " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "18", " ", \(my\^2\), " ", \((my\^2 - mw\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "9", " ", \((mw\^2 - 4\ my\^2)\), " ", \((mw\^2 - my\^2)\), " ",
                 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"18", " ", \(my\^2\), " ", \((my\^2 - mw\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "9", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"9", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"6", " ", \((mw\^2 - my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "18", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"6", " ", \((3\ mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"6", " ", \((mw\^2 - my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "18", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"6", " ", \((3\ mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"6", " ", \((mw\^2 - my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "36", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"12", " ", \((3\ mw\^2 - 4\ my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"36", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"6", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"6", " ", \((mw\^2 - my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "27", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \(my\^2\), " ", \(\(B\_0\)(0, my\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"3", " ", \((9\ mw\^2 - 5\ my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{
              "54", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"54", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"36", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "+", 
            FractionBox[
              RowBox[{"6", " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"12", " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{"2", " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              RowBox[{
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    FormBox["p",
                      "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                    "\[NoBreak]", 
                    FormBox["q",
                      "TraditionalForm"]}]}], "+", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}]], "-", 
            FractionBox[
              RowBox[{
              "24", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"24", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "24", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"24", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "36", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"36", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "36", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"36", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "-", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "4"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "4"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "24", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"24", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "24", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"24", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}],
                      "TraditionalForm"], ")"}], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "4"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "36", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"36", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \(\((mw\^2 - my\^2)\)\^2\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \(\((mw\^2 - my\^2)\)\^2\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], "2"], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{
              "36", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{"36", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["p",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "+", 
            FractionBox[
              RowBox[{
              "12", " ", \((mw\^2 - my\^2)\), 
                " ", \(\(B\_0\)(0, mw\^2, my\^2)\), " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]], "-", 
            FractionBox[
              RowBox[{"12", " ", \((mw\^2 - my\^2)\), " ", 
                RowBox[{\(B\_0\), "(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ",", \(mw\^2\), 
                  ",", \(my\^2\), ")"}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], 
                  FormBox[
                    FormBox["\[Mu]",
                      "TraditionalForm"],
                    "TraditionalForm"]], " ", 
                RowBox[{
                  FormBox["p",
                    "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                  "\[NoBreak]", 
                  FormBox["q",
                    "TraditionalForm"]}], " ", 
                SuperscriptBox[
                  FormBox["q",
                    "TraditionalForm"], "2"]}], 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    SuperscriptBox[
                      FormBox["p",
                        "TraditionalForm"], "2"], "+", 
                    RowBox[{"2", " ", 
                      RowBox[{
                        FormBox["p",
                          "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                        "\[NoBreak]", 
                        FormBox["q",
                          "TraditionalForm"]}]}], "+", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}], ")"}], "2"]]}], ")"}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
It is not zero but do not panic. It seems that we need to apply PaVeReduce\
\>", "Text"],

Cell[BoxData[
    \(\(SetOptions[B0, BReduce \[Rule] True];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[PaVeReduce[NewM /. mu \[Rule] my]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(-\(1\/48\)\), " ", "\[ImaginaryI]", " ", \(\[Pi]\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                FormBox["q",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{\(26\ mw\^2\), "+", \(4\ my\^2\), "-", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "-", 
                  RowBox[{"17", " ", 
                    SuperscriptBox[
                      FormBox["q",
                        "TraditionalForm"], "2"]}]}], ")"}]}], "+", 
            RowBox[{
              SuperscriptBox[
                FormBox["p",
                  "TraditionalForm"], 
                FormBox[
                  FormBox["\[Mu]",
                    "TraditionalForm"],
                  "TraditionalForm"]], " ", 
              RowBox[{"(", 
                RowBox[{\(2\ mw\^2\), "+", \(4\ my\^2\), "-", 
                  SuperscriptBox[
                    FormBox["p",
                      "TraditionalForm"], "2"], "-", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      FormBox["p",
                        "TraditionalForm"], "\[NoBreak]", "\[CenterDot]", 
                      "\[NoBreak]", 
                      FormBox["q",
                        "TraditionalForm"]}]}], "-", 
                  SuperscriptBox[
                    FormBox["q",
                      "TraditionalForm"], "2"]}], ")"}]}]}], ")"}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
It is still not zero, which is evidently wrong. What is going on? It seems \
that there is an error somewhere in the code and has to do with the ordering \
of the denominators. \
\>", "Text"]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{1009, 657},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1.25
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 57, 1, 35, "Input"],
Cell[1777, 52, 620, 20, 39, "Text"],
Cell[2400, 74, 63, 0, 38, "Text"],
Cell[2466, 76, 3456, 82, 47, "Text"],
Cell[5925, 160, 164, 2, 37, "Text"],
Cell[6092, 164, 43, 0, 38, "Text"],
Cell[6138, 166, 167, 4, 35, "Input"],
Cell[6308, 172, 25, 0, 38, "Text"],
Cell[6336, 174, 62, 1, 35, "Input"],
Cell[6401, 177, 49, 1, 35, "Input"],
Cell[6453, 180, 40, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[6518, 184, 61, 1, 35, "Input"],
Cell[6582, 187, 52, 1, 35, "Output"]
}, Open  ]],
Cell[6649, 191, 61, 0, 38, "Text"],
Cell[6713, 193, 165, 4, 35, "Input"],
Cell[6881, 199, 165, 4, 35, "Input"],
Cell[7049, 205, 52, 1, 35, "Input"],
Cell[7104, 208, 55, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[7184, 212, 64, 1, 35, "Input"],
Cell[7251, 215, 495423, 11920, 6042, "Output"]
}, Open  ]],
Cell[502689, 12138, 98, 2, 38, "Text"],
Cell[502790, 12142, 74, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[502889, 12147, 76, 1, 35, "Input"],
Cell[502968, 12150, 2052, 52, 52, "Output"]
}, Open  ]],
Cell[505035, 12205, 201, 4, 59, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

